@@ -17,9 +17,8 @@
 #include "lockable.h"
 #include "cleaner.h"
 #include "tcpconnect.h"
-
+#include "ebrunner.h"
 #include "fileitem.h"
-#include "dlcon.h"
 #include "fileio.h"
 
 #ifdef HAVE_SYS_MOUNT_H
@@ -42,8 +41,13 @@
 #define MIN(a,b) ( (a<=b)?a:b)
 #endif
 
+#include <thread>
+
 using namespace std;
 using namespace acng;
+dlcon *dler;
+
+//#define SPAM
 
 #ifdef SPAM
 #define _cerr(x) cerr << x
@@ -157,7 +161,6 @@ public:
 
 	int Read(char *retbuf, const char *path, off_t pos, size_t len)
 	{
-		dlcon dler(true, 0);
 		tHttpUrl uri = proxyUrl;
 		uri.sPath += baseUrl.sHost
 		// + ":" + ( baseUrl.sPort.empty() ? baseUrl.sPort : "80")
@@ -287,8 +290,7 @@ public:
 
 		tFitem *pFi = new tFitem(retbuf, len, pos, fid, bIsFirst);
 		tFileItemPtr spFi(static_cast<fileitem*>(pFi));
-		dler.AddJob(spFi, &uri, 0, 0, 0, cfg::REDIRMAX_DEFAULT, false);
-		dler.WorkLoop();
+		dler->AddJob(spFi, &uri, 0, 0, 0, cfg::REDIRMAX_DEFAULT, nullptr, false);
 		int nHttpCode(100);
 		pFi->WaitForFinish(&nHttpCode);
 		bIsFirst=false;
@@ -327,8 +329,6 @@ public:
 		}
 		// ok, not cached, do the hard way
 
-		dlcon dler(true, 0);
-
 		tHttpUrl uri = proxyUrl;
 		uri.sPath += baseUrl.sHost
 		// + ":" + ( baseUrl.sPort.empty() ? baseUrl.sPort : "80")
@@ -360,8 +360,7 @@ public:
 			}
 		};
 		auto probe(make_shared<tFitemProbe>());
-		dler.AddJob(probe, &uri, 0, 0, 0, cfg::REDIRMAX_DEFAULT, false);
-		dler.WorkLoop();
+		dler->AddJob(probe, &uri, 0, 0, 0, cfg::REDIRMAX_DEFAULT, nullptr, false);
 		int nHttpCode(100);
 		fileitem::FiStatus res = probe->WaitForFinish(&nHttpCode);
 		stbuf.st_size = atoofft(probe->GetHeaderUnlocked().h[header::CONTENT_LENGTH], 0);
@@ -630,6 +629,7 @@ void _ExitUsage() {
 #define barf(x) { cerr << endl << "ERROR: " << x <<endl; exit(1); }
 #define erUsage { _ExitUsage(); }
 
+
 int main(int argc, char *argv[])
 {
 	using namespace acng;
@@ -670,7 +670,7 @@ int main(int argc, char *argv[])
    
    if(argc<4)
       barf("Not enough arguments, try --help.\n");
-   
+
    cfg::agentname = "ACNGFS";
    cfg::agentheader="User-Agent: ACNGFS\r\n";
    cfg::requestapx = "User-Agent: ACNGFS\r\nX-Original-Source: 42\r\n";
@@ -740,5 +740,9 @@ int main(int argc, char *argv[])
    argv[nMyArgCount]=argv[0]; // application path
    argv=&argv[nMyArgCount];
    argc-=nMyArgCount;
+
+   evabaseFreeFrunner eb(g_tcp_con_factory);
+   dler = &eb.dl;
+
    return my_fuse_main(argc, argv);
 }
