@@ -41,7 +41,7 @@ public:
 	enum eType : char
 	{
 		TYPE_EXFILEITEM, TYPE_ACFGHOOKS, /* TYPE_EXDNS,*/ TYPE_EXCONNS,
-		DNS_CACHE,
+	//	DNS_CACHE,
 		ETYPE_MAX
 	};
 	void ScheduleFor(time_t when, eType what);
