@@ -10,10 +10,10 @@ class dlcon;
 
 class conn // : public tRunable
 {
-	struct Impl;
+        class Impl;
 	Impl *_p;
 public:
-	conn(unique_fd fdId, const char *client);
+        conn(int fdId, const char *client);
 	virtual ~conn();
 	void WorkLoop();
 
