@@ -2,6 +2,7 @@
 #define _META_H
 
 #include "config.h"
+#include "sut.h"
 
 #if defined(_POSIX_C_SOURCE) && (_POSIX_C_SOURCE < 200112L)
 #undef _POSIX_C_SOURCE
@@ -36,6 +37,12 @@
 #endif
 
 
+#ifdef __GNUC__
+#define WARN_UNUSED  __attribute__ ((warn_unused_result))
+#else
+#define WARN_UNUSED
+#endif
+
 // little STFU helper
 #if __GNUC__ >= 7
 #define __just_fall_through [[fallthrough]]
@@ -107,18 +114,7 @@ int getUUID();
 
 #define SPACECHARS " \f\n\r\t\v"
 
-#ifdef COMPATGCC47
-class tStrMap : public std::map<mstring, mstring>
-{
-public:
-	void emplace(cmstring& key, cmstring& value)
-	{
-		EMPLACE_PAIR_COMPAT(*this, key, value);
-	}
-};
-#else
 typedef std::map<mstring, mstring> tStrMap;
-#endif
 
 inline void trimFront(mstring &s, LPCSTR junk=SPACECHARS)
 {
@@ -249,7 +245,8 @@ public:
 	inline cmstring& GetDefaultPortForProto() const {
 		return bSSL ? sDefPortHTTPS : sDefPortHTTP;
 	}
-	inline cmstring& GetPort() const { return !sPort.empty() ? sPort : GetDefaultPortForProto(); }
+	inline cmstring& GetPort(cmstring& szDefVal) const { return !sPort.empty() ? sPort : szDefVal; }
+	inline cmstring& GetPort() const { return GetPort(GetDefaultPortForProto()); }
 
 	inline tHttpUrl(cmstring &host, cmstring& port, bool ssl) :
 			sPort(port), sHost(host), bSSL(ssl)
@@ -489,23 +486,31 @@ struct tDtorEx {
 	inline ~tDtorEx() { _action(); }
 };
 
-// unique_ptr semantics on a very custom type
+// unique_ptr semantics (almost) on a non-pointer type
 template<typename T, void TFreeFunc(T), T inval_default>
 struct auto_raii
 {
     T m_p;
-    auto_raii(T xp) : m_p(xp) {}
+    auto_raii() : m_p(inval_default) {}
+    explicit auto_raii(T xp) : m_p(xp) {}
     ~auto_raii() { if (m_p != inval_default) TFreeFunc(m_p); }
     T release() { auto ret=m_p; m_p = inval_default; return ret;}
     T get() const { return m_p; }
-    auto_raii() = delete;
     auto_raii(const auto_raii&) = delete;
     auto_raii(auto_raii && other)
-    {
-    	m_p = other.m_p;
-    	other.m_p = inval_default;
-    }
-    operator bool() const { return inval_default != m_p;}
+	{
+		m_p = other.m_p;
+		other.m_p = inval_default;
+	}
+	auto_raii& reset(auto_raii &&other)
+	{
+		if (&other == this)
+			return *this;
+		m_p = other.m_p;
+		other.m_p = inval_default;
+		return *this;
+	}
+    bool valid() const { return inval_default != m_p;}
 };
 
 // from bgtask.cc
@@ -570,8 +575,6 @@ public:
 		return &tv;
 	}
 };
-
-extern std::atomic<bool> g_global_shutdown;
 }
 
 #endif // _META_H
