@@ -120,6 +120,8 @@ MapNameToString n2sTbl[] = {
 		,{  "BadRedirDetectMime",      &badredmime}
 		,{	"OptProxyCheckCommand",	   &optProxyCheckCmd}
 		,{  "BusAction",                &sigbuscmd} // "Special debugging helper, see manual!"
+        ,{  "EvDnsResolvConf",		 	&dnsresconf}
+
 };
 
 MapNameToInt n2iTbl[] = {
@@ -160,6 +162,7 @@ MapNameToInt n2iTbl[] = {
 		,{  "OptProxyCheckInterval",             &optProxyCheckInt, nullptr,    10, false}
 		,{  "TrackFileUse",		             	 &trackfileuse,		nullptr,    10, false}
         ,{  "ReserveSpace",                      &allocspace, 		nullptr ,   10, false}
+        ,{  "EvDnsOpts",                	     &dnsopts,	 		nullptr ,   10, false}
 
         // octal base interpretation of UNIX file permissions
 		,{  "DirPerms",                          &dirperms,         nullptr,    8, false}
@@ -416,6 +419,11 @@ bool DegradedMode()
 	return degraded.load();
 }
 
+void DegradedMode(bool setVal)
+{
+	degraded.store(setVal);
+}
+
 inline void _FixPostPreSlashes(string &val)
 {
 	// fix broken entries
@@ -1140,6 +1148,9 @@ void PostProcConfig()
 	   fasttimeout = 0;
    }
 
+   if(RESERVED_DEFVAL == stucksecs)
+	   stucksecs = 2 * (maxtempdelay + 3);
+
    if(RESERVED_DEFVAL == forwardsoap)
 	   forwardsoap = !forcemanaged;
 
