@@ -201,13 +201,21 @@ void misc(const string & sLine, const char cLogType)
 		fStat.flush();
 }
 
-void ACNG_API err(const char *msg, const char *client)
+void err(const char *msg, size_t len)
 {
 	if(!logIsEnabled)
 		return;
 
+	auto xlog = [msg, len](ostream& chan){
+		static char buf[32];
+		const time_t tm=time(nullptr);
+		ctime_r(&tm, buf);
+		buf[24]='|';
+		chan.write(buf, 25).write(msg, len).write(szNEWLINE, 1);
+		if(cfg::debug & LOG_FLUSH)
+			chan.flush();
+	};
 	lockguard g(&mx);
-
 	if(!fErr.is_open())
 	{
 #ifdef DEBUG // basic debugging of acngtool
@@ -215,23 +223,11 @@ void ACNG_API err(const char *msg, const char *client)
 #endif
 		return;
 	}
-	
-	static char buf[32];
-	const time_t tm=time(nullptr);
-	ctime_r(&tm, buf);
-	buf[24]=0;
-	fErr << buf << '|';
-	if(client)
-		fErr << client << ": ";
-	fErr << msg << '\n';
-
+	xlog(fErr);
 #ifdef DEBUG
-	if(cfg::debug & log::LOG_DEBUG)
-		cerr << buf << msg <<endl;
+	if(cfg::debug & LOG_DEBUG)
+		xlog(cerr);
 #endif
-
-	if(cfg::debug & log::LOG_DEBUG)
-		fErr.flush();
 }
 
 void ACNG_API flush()
@@ -436,11 +432,14 @@ tErrnoFmter::tErrnoFmter(const char *prefix)
 
 #ifdef DEBUG
 
-thread_local unsigned gtls_indent_level=0;
+thread_local unsigned gtls_indent_level = 0;
 
 t_logger::t_logger(const char *szFuncName,  const void * ptr, const char *szIndentString)
 : m_szName(szFuncName), m_szIndentString(szIndentString)
 {
+	if(!cfg::debug)
+		return;
+
 	// explicit truncation, don't care about the PID part of it
 	auto id = uint32_t((uint64_t)pthread_self());
 	m_threadNameBEGIN = std::string(" [T:") + std::to_string(id);
@@ -453,15 +452,15 @@ t_logger::t_logger(const char *szFuncName,  const void * ptr, const char *szInde
 
 t_logger::~t_logger()
 {
+	if(!cfg::debug)
+		return;
+	gtls_indent_level--;
+
 	if(m_szName)
 	{
-		gtls_indent_level--;
 		GetFmter(" << ") << m_szName << m_threadNameBEGIN << m_objectIdEND;
 	}
-	else
-	{
-		// otherwise there is unfinished string in buffer for the printing
-	}
+	// otherwise there is unfinished string in buffer for the printing
 	Write();
 }
 
@@ -470,7 +469,7 @@ t_logger::~t_logger()
  */
 tSS & t_logger::GetFmter4End()
 {
-	gtls_indent_level--;
+	//gtls_indent_level--;
 	auto& ret = GetFmter();
 	GetFmter(" << ") << m_szName << m_threadNameBEGIN << m_objectIdEND;
 	m_szName = nullptr;
@@ -482,7 +481,7 @@ tSS & t_logger::GetFmter4End()
 tSS & t_logger::GetFmter(const char *szPrefix)
 {
 	m_strm.clear();
-	for(unsigned i=0;i<gtls_indent_level;i++)
+	for(unsigned i=0; i < gtls_indent_level; i++)
 		m_strm << m_szIndentString;
 	if(szPrefix)
 		m_strm << szPrefix;
