@@ -46,6 +46,7 @@
 #include "filereader.h"
 #include "csmapping.h"
 #include "cleaner.h"
+#include "ebrunner.h"
 
 using namespace std;
 using namespace acng;
@@ -82,8 +83,8 @@ struct ACNG_API CPrintItemFactory : public IFitemFactory
 				m_nSizeChecked = m_nSizeSeen = 0;
 				return m_status = FIST_INITED;
 			}
-			virtual int GetFileFd() override
-			{	return 1;}; // something, don't care for now
+			virtual unique_fd GetFileFd() override
+			{	return unique_fd();}; // something, don't care for now
 			virtual bool DownloadStartedStoreHeader(const header &h, size_t, const char *,
 					bool, bool&) override
 			{
@@ -128,9 +129,9 @@ SHARED_PTR<fileitem> CreateStdoutItem()
 			m_nSizeChecked = m_nSizeSeen = 0;
 			return m_status = FIST_INITED;
 		}
-		virtual int GetFileFd() override
+		virtual unique_fd GetFileFd() override
 		{
-			return 1;
+			return unique_fd();
 		}
 		; // something, don't care for now
 		virtual bool DownloadStartedStoreHeader(const header &h, size_t, const char*, bool, bool&)
@@ -211,10 +212,8 @@ SHARED_PTR<fileitem> CreateReportItem()
 			m_nSizeChecked = m_nSizeSeen = 0;
 			return m_status = FIST_INITED;
 		}
-		virtual int GetFileFd() override
-		{
-			return 1;
-		}
+			virtual unique_fd GetFileFd() override
+			{	return unique_fd();}; // something, don't care for now
 		; // something, don't care for now
 		virtual bool DownloadStartedStoreHeader(const header &h, size_t, const char*, bool, bool&)
 				override
@@ -281,20 +280,17 @@ SHARED_PTR<fileitem> CreateReportItem()
 	return make_shared<tRepItem>();
 }
 
-void DownloadItem(const tHttpUrl &url, IDlConFactory &pDlconFac, const SHARED_PTR<fileitem> &fi)
+void DownloadItem(const tHttpUrl &url, dlcon &dlConnector, const SHARED_PTR<fileitem> &fi)
 {
-	dlcon dl("", nullptr, &pDlconFac);
-	std::thread dlThread([&]() {dl.WorkLoop();});
-	dl.AddJob(fi, &url, nullptr, nullptr, 0, cfg::REDIRMAX_DEFAULT, false);
+	dlConnector.AddJob(fi, &url, nullptr, nullptr, 0,
+			cfg::REDIRMAX_DEFAULT, nullptr, false);
 	int st;
 	auto fistatus = fi->WaitForFinish(&st);
 	// just be sure to set a proper error code
 	if(fistatus != fileitem::FIST_COMPLETE && fi->GetHeader().getStatus() < 400)
 		fi->GetHeader().frontLine = "909 Incomplete download";
-	dl.SignalStop();
-	dlThread.join();
 }
-int wcat(LPCSTR url, LPCSTR proxy, IFitemFactory*, IDlConFactory *pdlconfa = &g_tcp_con_factory);
+int wcat(LPCSTR url, LPCSTR proxy, IFitemFactory*, const IDlConFactory &pdlconfa = g_tcp_con_factory);
 
 static void usage(int retCode = 0, LPCSTR cmd = nullptr)
 {
@@ -515,30 +511,57 @@ typedef deque<tPtrLen> tPatchSequence;
 // might need to access the last line externally
 unsigned long rangeStart(0), rangeLast(0);
 
-inline bool patchChunk(tPatchSequence& idx, LPCSTR pline, size_t len, tPatchSequence chunk)
+inline bool patchChunk(tPatchSequence& idx, LPCSTR pline, tPatchSequence diffPayload)
 {
-	char op = 0x0;
-	auto n = sscanf(pline, "%lu,%lu%c\n", &rangeStart, &rangeLast, &op);
-	if (n == 1) // good enough
-		rangeLast = rangeStart, op = pline[len - 2];
-	else if(n!=3)
-		return false; // bad instruction
+	bool append = false;
+	char *pEnd = nullptr;
+	auto n = strtoul(pline, &pEnd, 10);
+	if (!pEnd || pline == pEnd)
+		return false;
+	rangeStart = n;
+
+	switch (*pEnd)
+	{
+	case ',':
+	{
+		pline = pEnd + 1;
+		n = strtoul(pline, &pEnd, 10);
+		if (!pEnd || pline == pEnd || (*pEnd != 'c' && *pEnd != 'd'))
+			return false;
+		rangeLast = n;
+		break;
+	}
+	case 'a':
+		append = true;
+		__just_fall_through;
+	case 'c':
+	case 'd':
+	{
+		// that is just one line?
+		rangeLast = rangeStart = n;
+		break;
+	}
+	default:
+		return false;
+	}
+
 	if (rangeStart > idx.size() || rangeLast > idx.size() || rangeStart > rangeLast)
 		return false;
-	if (op == 'a')
-		idx.insert(idx.begin() + (size_t) rangeStart + 1, chunk.begin(), chunk.end());
+
+	if (append)
+		idx.insert(idx.begin() + (size_t) rangeStart + 1, diffPayload.begin(), diffPayload.end());
 	else
 	{
 		size_t i = 0;
-		for (; i < chunk.size(); ++i, ++rangeStart)
+		for (; i < diffPayload.size(); ++i, ++rangeStart)
 		{
 			if (rangeStart <= rangeLast)
-				idx[rangeStart] = chunk[i];
+				idx[rangeStart] = diffPayload[i];
 			else
 				break; // new stuff bigger than replaced range
 		}
-		if (i < chunk.size()) // not enough space :-(
-			idx.insert(idx.begin() + (size_t) rangeStart, chunk.begin() + i, chunk.end());
+		if (i < diffPayload.size()) // not enough space :-(
+			idx.insert(idx.begin() + (size_t) rangeStart, diffPayload.begin() + i, diffPayload.end());
 		else if (rangeStart - 1 != rangeLast) // less data now?
 			idx.erase(idx.begin() + (size_t) rangeStart, idx.begin() + (size_t) rangeLast + 1);
 	}
@@ -551,12 +574,12 @@ inline bool patchChunk(tPatchSequence& idx, LPCSTR pline, size_t len, tPatchSequ
  */
 struct TUdsFactory : public ::acng::IDlConFactory
 {
-	void RecycleIdleConnection(tDlStreamHandle &handle) override
+	void RecycleIdleConnection(tDlStreamHandle &handle) const override
 	{
 		// keep going, no recycling/restoring
 	}
 	tDlStreamHandle CreateConnected(cmstring&, cmstring&, mstring& sErrorOut, bool*,
-			cfg::tRepoData::IHookHandler*, bool, int, bool) override
+			cfg::tRepoData::IHookHandler*, bool, int, bool) const override
 	{
 		struct udsconnection: public tcpconnect
 		{
@@ -654,8 +677,9 @@ int maint_job()
 		DBGQLOG("Trying UDS path")
 		auto fi =CreateReportItem();
 		url.sHost = FAKE_UDS_HOSTNAME;
-		TUdsFactory udsConFac;
-		DownloadItem(url, udsConFac, fi);
+		TUdsFactory udsFac;
+		evabaseFreeFrunner eb(udsFac);
+		DownloadItem(url, eb.dl, fi);
 		response_ok = fi->GetHeader().getStatus() == 200;
 		DBGQLOG("UDS result: " << response_ok)
 	}
@@ -672,8 +696,9 @@ int maint_job()
 		for (const auto &tgt : hostips)
 		{
 			url.sHost = tgt;
+			evabaseFreeFrunner eb(g_tcp_con_factory);
 			auto fi = CreateReportItem();
-			DownloadItem(url, g_tcp_con_factory, fi);
+			DownloadItem(url, eb.dl, fi);
 			response_ok = fi->GetHeader().getStatus() == 200;
 			if (response_ok)
 				break;
@@ -695,19 +720,19 @@ int patch_file(string sBase, string sPatch, string sResult)
 		return -2;
 	auto buf = frBase.GetBuffer();
 	auto size = frBase.GetSize();
-	tPatchSequence idx;
-	idx.emplace_back(buf, 0); // dummy entry to avoid -1 calculations because of ed numbering style
+	tPatchSequence lines;
+	lines.emplace_back(buf, 0); // dummy entry to avoid -1 calculations because of ed numbering style
 	for (auto p = buf; p < buf + size;)
 	{
 		LPCSTR crNext = strchr(p, '\n');
 		if (crNext)
 		{
-			idx.emplace_back(p, crNext + 1 - p);
+			lines.emplace_back(p, crNext + 1 - p);
 			p = crNext + 1;
 		}
 		else
 		{
-			idx.emplace_back(p, buf + size - p);
+			lines.emplace_back(p, buf + size - p);
 			break;
 		}
 	}
@@ -715,10 +740,11 @@ int patch_file(string sBase, string sPatch, string sResult)
 	auto pbuf = frPatch.GetBuffer();
 	auto psize = frPatch.GetSize();
 	tPatchSequence chunk;
-	LPCSTR cmd =0;
-	size_t cmdlen = 0;
+	LPCSTR patchCmd =0;
+	size_t patchCmdLen = 0;
 	for (auto p = pbuf; p < pbuf + psize;)
 	{
+		// accumulate lines until chunk is consumed
 		LPCSTR crNext = strchr(p, '\n');
 		size_t len = 0;
 		LPCSTR line=p;
@@ -734,48 +760,51 @@ int patch_file(string sBase, string sPatch, string sResult)
 		}
 		p=crNext+1;
 
-		bool gogo = (len == 2 && *line == '.');
-		if(!gogo)
+		bool hunkOK = (len == 2 && *line == '.');
+		if(!hunkOK)
 		{
-			if(!cmdlen)
+			if(!patchCmdLen)
 			{
 				if(!strncmp("s/.//\n", line, 6))
 				{
 					// oh, that's the fix-the-last-line command :-(
 					if(rangeStart)
-						idx[rangeStart].first = ".\n", idx[rangeStart].second=2;
+					{
+						lines[rangeStart].first = ".\n";
+						lines[rangeStart].second=2;
+					}
 					continue;
 				}
 				else if(line[0] == 'w')
 					continue; // don't care, we know the target
 
-				cmdlen = len;
-				cmd = line;
+				patchCmdLen = len;
+				patchCmd = line;
 
 				if(len>2 && line[len-2] == 'd')
-					gogo = true; // no terminator to expect
+					hunkOK = true; // no terminator to expect
 			}
 			else
 				chunk.emplace_back(line, len);
 		}
 
-		if(gogo)
+		if(hunkOK)
 		{
-			if(!patchChunk(idx, cmd, cmdlen, chunk))
+			if(!patchChunk(lines, patchCmd, chunk))
 			{
 				cerr << "Bad patch line: ";
-				cerr.write(cmd, cmdlen);
+				cerr.write(patchCmd, patchCmdLen);
 				exit(EINVAL);
 			}
 			chunk.clear();
-			cmdlen = 0;
+			patchCmdLen = 0;
 		}
 	}
 	ofstream res(sResult.c_str());
 	if(!res.is_open())
 		return -3;
 
-	for(const auto& kv : idx)
+	for(const auto& kv : lines)
 		res.write(kv.first, kv.second);
 	res.flush();
 //	dump_proc_status_always();
@@ -1097,7 +1126,7 @@ int main(int argc, const char **argv)
 	return g_exitCode;
 }
 
-int wcat(LPCSTR surl, LPCSTR proxy, IFitemFactory* fac, IDlConFactory *pDlconFac)
+int wcat(LPCSTR surl, LPCSTR proxy, IFitemFactory* fac, const IDlConFactory &pDlconFac)
 {
 	cfg::dnscachetime=0;
 	cfg::persistoutgoing=0;
@@ -1113,18 +1142,20 @@ int wcat(LPCSTR surl, LPCSTR proxy, IFitemFactory* fac, IDlConFactory *pDlconFac
 	string xurl(surl);
 	if(!url.SetHttpUrl(xurl, false))
 		return -2;
-	dlcon dl(true, nullptr, pDlconFac);
+	if(url.bSSL)
+		globalSslInit();
+
+	evabaseFreeFrunner eb(pDlconFac);
 
 	auto fi=fac->Create();
-	dl.AddJob(fi, &url, nullptr, nullptr, 0, cfg::REDIRMAX_DEFAULT, false);
-	dl.WorkLoop();
-	auto fistatus = fi->GetStatus();
-	header hh = fi->GetHeader();
-	int st=hh.getStatus();
-
+	eb.dl.AddJob(fi, &url, nullptr, nullptr, 0, cfg::REDIRMAX_DEFAULT,
+			nullptr, false);
+	int st;
+	auto fistatus = fi->WaitForFinish(&st);
 	if(fistatus == fileitem::FIST_COMPLETE && st == 200)
 		return EXIT_SUCCESS;
 
+	auto hh = fi->GetHeader();
 	// don't reveal passwords
 	auto xpos=xurl.find('@');
 	if(xpos!=stmiss)
