@@ -193,9 +193,9 @@ static void SetupCacheDir()
 	buf << cacheDirSlash << "testfile." << tv.tv_usec * tv.tv_sec * (LPCSTR(buf.wptr()) - LPCSTR(&tv));
 	mkbasedir(buf.c_str()); // try or force its directory creation
 	int t=open( buf.c_str(), O_WRONLY | O_CREAT | O_TRUNC, 00644);
-	if (t>=0)
+	if (t != -1)
 	{
-		forceclose(t);
+		checkforceclose(t);
 		if(0==unlink(buf.c_str()))
 			return;
 	}
