@@ -44,12 +44,14 @@ deque<decltype(dns_cache)::iterator> dns_exp_q;
 struct tDnsResContext
 {
 	string sHost, sPort;
+	std::shared_ptr<CDnsBase> resolver;
 	list<CAddrInfo::tDnsResultReporter> cbs;
 };
 unordered_map<string,tDnsResContext*> g_active_resolver_index;
 
 // this shall remain global and forever, for last-resort notifications
-SHARED_PTR<CAddrInfo> fail_hint=make_shared<CAddrInfo>("503 Fatal system error within apt-cacher-ng processing");
+LPCSTR sGenericErrorStatus = "503 Fatal system error within apt-cacher-ng processing";
+auto fail_hint = make_shared<CAddrInfo>(sGenericErrorStatus);
 
 
 /**
@@ -141,19 +143,20 @@ void CAddrInfo::Resolve(cmstring & sHostname, cmstring &sPort, tDnsResultReporte
 	auto temp_ctx = new tDnsResContext {
 		sHostname,
 		sPort,
+		std::shared_ptr<CDnsBase>(),
 		list<CAddrInfo::tDnsResultReporter> {move(rep)}
 	};
-
+	// keep a reference on the dns base to extend its lifetime
 	auto cb_invoke_dns_res = [temp_ctx](bool canceled)
 	{
 		auto args = unique_ptr<tDnsResContext>(temp_ctx); //temporarily owned here
 		if(!args || args->cbs.empty() || !(args->cbs.front())) return; // heh?
 		LOGSTARTFUNCsx(temp_ctx->sHost);
 
-		if(canceled || evabase::in_shutdown)
+		if (AC_UNLIKELY(canceled || evabase::in_shutdown))
 		{
-			auto err_hint = make_shared<CAddrInfo>(evutil_gai_strerror(EAI_SYSTEM));
-			args->cbs.front()(err_hint);
+			args->cbs.front()(make_shared<CAddrInfo>(
+					evutil_gai_strerror(EAI_SYSTEM)));
 			return;
 		}
 
@@ -174,7 +177,15 @@ void CAddrInfo::Resolve(cmstring & sHostname, cmstring &sPort, tDnsResultReporte
 			resIt->second->cbs.splice(resIt->second->cbs.end(), args->cbs);
 			return;
 		}
-		// ok, invoke a completely new DNS lookup operation
+
+		// ok, this is fresh, invoke a completely new DNS lookup operation
+		temp_ctx->resolver = evabase::GetDnsBase();
+		if (AC_UNLIKELY(!temp_ctx->resolver || !temp_ctx->resolver->get()))
+		{
+			args->cbs.front()(make_shared<CAddrInfo>("503 Bad DNS configuration"));
+			return;
+		}
+
 		g_active_resolver_index[key] = args.get();
 		static bool filter_specific = (cfg::conprotos[0] != PF_UNSPEC && cfg::conprotos[1] == PF_UNSPEC);
 		static const evutil_addrinfo default_connect_hints =
@@ -187,7 +198,8 @@ void CAddrInfo::Resolve(cmstring & sHostname, cmstring &sPort, tDnsResultReporte
 			0, nullptr, nullptr, nullptr
 		};
 		auto pRaw = args.release(); // to be owned by the operation
-		evdns_getaddrinfo(evabase::dnsbase, pRaw->sHost.empty() ? nullptr : pRaw->sHost.c_str(),
+		evdns_getaddrinfo(temp_ctx->resolver->get(),
+				pRaw->sHost.empty() ? nullptr : pRaw->sHost.c_str(),
 				pRaw->sPort.empty() ? nullptr : pRaw->sPort.c_str(),
 				&default_connect_hints, CAddrInfo::cb_dns, pRaw);
 	};
@@ -200,4 +212,20 @@ CAddrInfo::~CAddrInfo()
 	if (m_rawInfo) evutil_freeaddrinfo(m_rawInfo);
 	m_tcpAddrInfo = m_rawInfo = nullptr;
 }
+
+void RejectPendingDnsRequests()
+{
+	for (auto& el: g_active_resolver_index)
+	{
+		if (!el.second)
+			continue;
+
+		for (const auto& action: el.second->cbs)
+		{
+			action(make_shared<CAddrInfo>(evutil_gai_strerror(EAI_SYSTEM)));
+		}
+		el.second->cbs.clear();
+	}
+}
+
 }
