@@ -9,7 +9,7 @@
 #include "meta.h"
 
 #include "cleaner.h"
-
+#include "evabase.h"
 #include "fileitem.h"
 #include "acfg.h"
 #include "caddrinfo.h"
@@ -25,7 +25,7 @@ namespace acng
 {
 
 // forward declation, see caddrinfo.cc
-time_t expireDnsCache();
+//time_t expireDnsCache();
 
 cleaner::cleaner(bool noop) : m_thr(0), m_noop(noop)
 {
@@ -46,7 +46,7 @@ void cleaner::WorkLoop()
 
 	while(true)
 	{
-		if (m_terminating || g_global_shutdown)
+		if (m_terminating || evabase::in_shutdown)
 			return;
 
 		decltype(stamps) snapshot;
@@ -61,7 +61,7 @@ void cleaner::WorkLoop()
 			auto &time_cand = snapshot[i];
 			if (time_cand > now)
 				continue;
-			if (m_terminating || g_global_shutdown)
+			if (m_terminating || evabase::in_shutdown)
 				return;
 
 			switch (eType(i))
@@ -77,13 +77,14 @@ void cleaner::WorkLoop()
 				USRDBG("tcpconnect::ExpireCache, nextRunTime now: " << time_cand);
 				break;
 			case TYPE_EXFILEITEM:
-				time_cand = fileItemMgmt::BackgroundCleanup();
+				time_cand = TFileItemUser::BackgroundCleanup();
 				USRDBG("fileitem::DoDelayedUnregAndCheck, nextRunTime now: " << time_cand);
 				break;
-			case DNS_CACHE:
+		/*	case DNS_CACHE:
 				time_cand = expireDnsCache();
 				USRDBG("dnsExpiration, nextRunTime now: " << time_cand);
 				break;
+				*/
 			case ETYPE_MAX:
 				return; // heh?
 			}
@@ -115,13 +116,13 @@ inline void * CleanerThreadAction(void *pVoid)
 
 void cleaner::ScheduleFor(time_t when, eType what)
 {
-	if(m_noop || g_global_shutdown)
+	if(m_noop || evabase::in_shutdown)
 		return;
 
 	setLockGuard;
 	if(m_thr == 0)
 	{
-		if(g_global_shutdown)
+		if(evabase::in_shutdown)
 			return;
 		Init();
 		stamps[what] = when;
@@ -171,7 +172,7 @@ void cleaner::dump_status()
 
 
 void ACNG_API dump_handler(evutil_socket_t fd, short what, void *arg) {
-	fileItemMgmt::dump_status();
+	TFileItemUser::dump_status();
 	cleaner::GetInstance().dump_status();
 	g_tcp_con_factory.dump_status();
 	cfg::dump_trace();
