@@ -18,7 +18,7 @@ using namespace std;
 #include <dirent.h>
 #include <algorithm>
 #include "maintenance.h"
-
+#include "evabase.h"
 #include <event2/buffer.h>
 
 #include <errno.h>
@@ -34,15 +34,11 @@ using namespace std;
 
 // hunting Bug#955793: [Heisenbug] evbuffer_write_atmost returns -1 w/o updating errno
 #define DBG_DISCONNECT //std::cerr << "DISCO? " << __LINE__ << std::endl;
-
 namespace acng
 {
 
 mstring sHttp11("HTTP/1.1");
 
-#define SPECIAL_FD -42
-inline bool IsValidFD(int fd) { return fd>=0 || SPECIAL_FD == fd; }
-
 tTraceData traceData;
 void cfg::dump_trace()
 {
@@ -91,8 +87,7 @@ public:
 	void SetRawResponseHeader(std::string s) override { m_sHeader = move(s); }
 	const std::string& GetRawResponseHeader() override { return m_sHeader; }
 
-	virtual int GetFileFd() override
-			{ return SPECIAL_FD; }; // something, don't care for now
+	unique_fd GetFileFd() override { return unique_fd(); }; // something, don't care for now
 	virtual bool DownloadStartedStoreHeader(const header & h, size_t, const char *,
 			bool, bool&) override
 	{
@@ -133,7 +128,7 @@ public:
 				// abandoned by the user?
 				if(m_status >= FIST_DLERROR)
 					LOGRET(false);
-				if(g_global_shutdown)
+				if(evabase::in_shutdown)
 					LOGRET(false);
 				auto in_buffer = evbuffer_get_length(m_q);
 				off_t nAddLimit = PT_BUF_MAX - in_buffer;
@@ -159,7 +154,7 @@ public:
 		LOGSTARTFUNC;
 		lockuniq g(this);
 		notifyAll();
-		if (m_status > FIST_COMPLETE || g_global_shutdown)
+		if (m_status > FIST_COMPLETE || evabase::in_shutdown)
 			return -1;
 		errno = -42;
 		auto ret = evbuffer_write_atmost(m_q, out_fd, nMax2SendNow);
@@ -183,8 +178,7 @@ public:
 class tGeneratedFitemBase : public fileitem
 {
 public:
-	virtual int GetFileFd() override
-	{ return SPECIAL_FD; }; // something, don't care for now
+	unique_fd GetFileFd() override { return unique_fd(); }; // something, don't care for now
 
 	tSS m_data;
 
@@ -246,15 +240,13 @@ job::~job()
 	int stcode = 200;
 	if(m_pItem) stcode = m_pItem.getFiPtr()->GetHeader().getStatus();
 
-	bool bErr=m_sFileLoc.empty() || stcode >= 400;
+	bool bErr = m_sFileLoc.empty() || stcode >= 400;
 
 	m_pParentCon->LogDataCounts(
 			m_sFileLoc + (bErr ? (miscError + ltos(stcode) + ']') : sEmptyString),
 			m_reqHead.h[header::XFORWARDEDFOR],
 			(m_pItem ? m_pItem.getFiPtr()->TakeTransferCount() : 0),
 			m_nAllDataCount, bErr);
-	
-	checkforceclose(m_filefd);
 }
 
 
@@ -309,7 +301,7 @@ inline void job::PrepareLocalDownload(const string &visPath,
 					seal();
 				}
 			};
-			m_pItem.RegisterFileitemLocalOnly(new dirredirect(visPath));
+			m_pItem = TFileItemUser::Create(make_shared<dirredirect>(visPath), false);
 			return;
 		}
 
@@ -322,8 +314,8 @@ inline void job::PrepareLocalDownload(const string &visPath,
 				seal(); // for now...
 			}
 		};
-		listing *p=new listing(visPath);
-		m_pItem.RegisterFileitemLocalOnly(p); // assign to smart pointer ASAP, operations might throw
+		auto p = make_shared<listing>(visPath);
+		m_pItem = TFileItemUser::Create(p, false);
 		tSS & page = p->m_data;
 
 		page << "<!DOCTYPE html>\n<html lang=\"en\"><head><title>Index of "
@@ -413,7 +405,7 @@ inline void job::PrepareLocalDownload(const string &visPath,
 			if(!sMimeType.empty())
 				m_head.set(header::CONTENT_TYPE, sMimeType);
 		};
-		virtual int GetFileFd() override
+		unique_fd GetFileFd() override
 		{
 			int fd=open(m_sPathRel.c_str(), O_RDONLY);
 		#ifdef HAVE_FADVISE
@@ -421,10 +413,10 @@ inline void job::PrepareLocalDownload(const string &visPath,
 			if(fd>=0)
 				posix_fadvise(fd, 0, m_nSizeChecked, POSIX_FADV_SEQUENTIAL);
 		#endif
-			return fd;
+			return unique_fd(fd);
 		}
 	};
-	m_pItem.RegisterFileitemLocalOnly(new tLocalGetFitem(absPath, stbuf));
+	m_pItem = TFileItemUser::Create(make_shared<tLocalGetFitem>(absPath, stbuf), false);
 }
 
 inline bool job::ParseRange()
@@ -503,7 +495,10 @@ void job::PrepareDownload(LPCSTR headBuf) {
 	if(rex::Match(sReqPath, rex::NASTY_PATH)
 			|| stmiss != sReqPath.find(MAKE_PTR_0_LEN("/_actmp"))
 			|| startsWithSz(sReqPath, "/_"))
+	{
+		LOG("ERROR: internal path or FS break-out attempt");
 		goto report_notallowed;
+	}
 
     try
 	{
@@ -516,6 +511,7 @@ void job::PrepareDownload(LPCSTR headBuf) {
 		if(!theUrl.SetHttpUrl(sReqPath, false))
 		{
 			m_eMaintWorkType=tSpecialRequest::workUSERINFO;
+			LOG("work type: USERINFO");
 			return;
 		}
 		LOG("refined path: " << theUrl.sPath << "\n on host: " << theUrl.sHost);
@@ -632,7 +628,7 @@ void job::PrepareDownload(LPCSTR headBuf) {
 
 		bForceFreshnessChecks = ( ! cfg::offlinemode && m_type == FILE_VOLATILE);
 
-		m_pItem.PrepareRegisteredFileItemWithStorage(m_sFileLoc, bForceFreshnessChecks);
+		m_pItem = TFileItemUser::Create(m_sFileLoc, bForceFreshnessChecks);
 	}
 	catch(const std::out_of_range&) // better safe...
 	{
@@ -687,7 +683,7 @@ void job::PrepareDownload(LPCSTR headBuf) {
     if( fistate < fileitem::FIST_DLGOTHEAD) // needs a downloader
     {
     	dbgline;
-    	if(!m_pParentCon->SetupDownloader(m_reqHead.h[header::XFORWARDEDFOR]))
+    	if(!m_pParentCon->SetupDownloader())
     	{
     		USRDBG( "Error creating download handler for "<<m_sFileLoc);
     		goto report_overload;
@@ -696,39 +692,41 @@ void job::PrepareDownload(LPCSTR headBuf) {
     	dbgline;
 try
 		{
-    		auto bHaveRedirects=(repoMapping.repodata && !repoMapping.repodata->m_backends.empty());
+			auto bHaveRedirects = (repoMapping.repodata
+					&& !repoMapping.repodata->m_backends.empty());
 
-    		if (cfg::forcemanaged && !bHaveRedirects)
-						goto report_notallowed;
+			if (cfg::forcemanaged && !bHaveRedirects)
+				goto report_notallowed;
 
-				if (!bPtMode)
-				{
-					// XXX: this only checks the first found backend server, what about others?
-					auto testUri= bHaveRedirects
-							? repoMapping.repodata->m_backends.front().ToURI(false)
-									+ repoMapping.sRestPath
-							: theUrl.ToURI(false);
-					if (rex::MatchUncacheable(testUri, rex::NOCACHE_TGT))
-						fistate = _SwitchToPtItem();
-				}
+			if (!bPtMode)
+			{
+				// XXX: this only checks the first found backend server, what about others?
+				auto testUri =
+						bHaveRedirects ?
+								repoMapping.repodata->m_backends.front().ToURI(
+										false) + repoMapping.sRestPath :
+								theUrl.ToURI(false);
+				if (rex::MatchUncacheable(testUri, rex::NOCACHE_TGT))
+					fistate = _SwitchToPtItem();
+			}
 
-					if (m_pParentCon->m_pDlClient->AddJob(m_pItem.getFiPtr(),
-							bHaveRedirects ? nullptr : &theUrl, repoMapping.repodata,
-							bHaveRedirects ? &repoMapping.sRestPath : nullptr,
-									(LPCSTR) ( bPtMode ? headBuf : nullptr),
-							cfg::redirmax, bPtMode))
-				{
-					ldbg("Download job enqueued for " << m_sFileLoc);
-				}
-				else
-				{
-					ldbg("PANIC! Error creating download job for " << m_sFileLoc);
-					goto report_overload;
-				}
-		}
-		catch(const std::bad_alloc&) // OOM, may this ever happen here?
+			if (m_pParentCon->SetupDownloader()->AddJob(m_pItem.getFiPtr(),
+					bHaveRedirects ? nullptr : &theUrl, repoMapping.repodata,
+					bHaveRedirects ? &repoMapping.sRestPath : nullptr,
+					(LPCSTR) (bPtMode ? headBuf : nullptr), cfg::redirmax,
+					m_reqHead.h[header::XFORWARDEDFOR], bPtMode))
+
+			{
+				ldbg("Download job enqueued for " << m_sFileLoc);
+			}
+			else
+			{
+				ldbg("PANIC! Error creating download job for " << m_sFileLoc);
+				goto report_overload;
+			}
+		} catch (const std::bad_alloc&) // OOM, may this ever happen here?
 		{
-			USRDBG( "Out of memory");
+			USRDBG("Out of memory");
 			goto report_overload;
 		};
 	}
@@ -765,7 +763,7 @@ job::eJobResult job::SendData(int confd, bool haveMoreJobs)
 {
 	LOGSTART("job::SendData");
 
-	if(m_eMaintWorkType)
+	if (m_eMaintWorkType != tSpecialRequest::eMaintWorkType::workNotSpecial)
 	{
 		tSpecialRequest::RunMaintWork(m_eMaintWorkType, m_sFileLoc, confd);
 		DBG_DISCONNECT
@@ -788,7 +786,7 @@ job::eJobResult job::SendData(int confd, bool haveMoreJobs)
 		
 		for(;;)
 		{
-			fistate=m_pItem.getFiPtr()->GetStatusUnlocked(nGoodDataSize);
+			fistate = m_pItem.getFiPtr()->GetStatusUnlocked(nGoodDataSize);
 			
 			LOG((int) fistate);
 			if (fistate > fileitem::FIST_COMPLETE)
@@ -888,8 +886,7 @@ job::eJobResult job::SendData(int confd, bool haveMoreJobs)
 						LOGRET(R_AGAIN);
 					}
 
-					m_filefd=m_pItem.getFiPtr()->GetFileFd();
-					if(!IsValidFD(m_filefd)) THROW_ERROR("503 IO error");
+					m_filefd.reset(m_pItem.getFiPtr()->GetFileFd());
 
 					m_state=m_bChunkMode ? STATE_SEND_CHUNK_HEADER : STATE_SEND_PLAIN_DATA;
 					ldbg("next state will be: " << (int) m_state);
@@ -911,7 +908,7 @@ job::eJobResult job::SendData(int confd, bool haveMoreJobs)
 
 					size_t nMax2SendNow=min(nGoodDataSize-m_nSendPos, m_nCurrentRangeLast+1-m_nSendPos);
 					ldbg("~sendfile: on "<< m_nSendPos << " up to : " << nMax2SendNow);
-					int n = m_pItem.getFiPtr()->SendData(confd, m_filefd, m_nSendPos, nMax2SendNow);
+					int n = m_pItem.getFiPtr()->SendData(confd, m_filefd.get(), m_nSendPos, nMax2SendNow);
 					ldbg("~sendfile: " << n << " new m_nSendPos: " << m_nSendPos);
 
 					if(n>0)
@@ -926,6 +923,7 @@ job::eJobResult job::SendData(int confd, bool haveMoreJobs)
 						THROW_ERROR("400 Client error");
 					
 					LOGRET(R_AGAIN);
+					break;
 				}
 				case(STATE_SEND_CHUNK_HEADER):
 				{
@@ -949,7 +947,7 @@ job::eJobResult job::SendData(int confd, bool haveMoreJobs)
 
 					if(m_nChunkRemainingBytes==0)
 						GOTOENDE; // done
-					int n = m_pItem.getFiPtr()->SendData(confd, m_filefd, m_nSendPos, m_nChunkRemainingBytes);
+					int n = m_pItem.getFiPtr()->SendData(confd, m_filefd.get(), m_nSendPos, m_nChunkRemainingBytes);
 					if(n<0)
 						THROW_ERROR("400 Client error");
 					m_nChunkRemainingBytes-=n;
@@ -963,6 +961,7 @@ job::eJobResult job::SendData(int confd, bool haveMoreJobs)
 						continue;
 					}
 					LOGRET(R_AGAIN);
+					break;
 				}
 				case(STATE_SEND_BUFFER):
 				{
@@ -996,6 +995,7 @@ job::eJobResult job::SendData(int confd, bool haveMoreJobs)
 						LOGRET(R_DISCON);
 					}
 					LOGRET(R_AGAIN);
+					break;
 				}
 			case (STATE_ALLDONE):
 				return return_stream_ok("STATE_ALLDONE?");
@@ -1210,7 +1210,7 @@ fileitem::FiStatus job::_SwitchToPtItem()
 	// Changing to local pass-through file item
 	LOGSTART("job::_SwitchToPtItem");
 	// exception-safe sequence
-	m_pItem.RegisterFileitemLocalOnly(new tPassThroughFitem(m_sFileLoc));
+	m_pItem = TFileItemUser::Create(make_shared<tPassThroughFitem>(m_sFileLoc), false);
 	return m_pItem.getFiPtr()->Setup(true);
 }
 
@@ -1236,9 +1236,9 @@ void job::SetErrorResponse(const char * errorLine, const char *szLocation, const
 		}
 	};
 
-	erroritem *p = new erroritem("noid", errorLine, bodytext);
+	auto p = make_shared<erroritem>("noid", errorLine, bodytext);
 	p->HeadRef().set(header::LOCATION, szLocation);
-	m_pItem.RegisterFileitemLocalOnly(p);
+	m_pItem = TFileItemUser::Create(p, false);
 	//aclog::err(tSS() << "fileitem is now " << uintptr_t(m_pItem.get()));
 	m_state=STATE_SEND_MAIN_HEAD;
 }
