@@ -149,11 +149,7 @@ tDeleter::tDeleter(const tRunParms& parms, const mstring& vmode)
 			char *end(0);
 			auto val = strtoul(tok.c_str()+3, &end, 36);
 			if(*end == 0 || *end=='&')
-#ifdef COMPATGCC47                           
-				files.insert(val);
-#else
 				files.emplace(val);
-#endif
 		}
 		else if(startsWithSz(tok, "blob="))
 			tok.swap(blob);
@@ -412,8 +408,8 @@ void tMarkupFileSend::SendProp(cmstring &key)
 			return SendChunk(m_fmtHelper.clean() << *pi);
 		return;
 	}
-	if (key == "serverip")
-		return SendChunk(GetHostname());
+	if (key == "serverhostport")
+		return SendChunk(GetMyHostPort());
 	if (key == "footer")
 		return SendChunk(GetFooter());
 
